/**
 * \file main.c
 * \brief The main function for shopeuros_client
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * \version 20090727
 * \author YuGiOhJCJ <yugiohjcj@1s.fr> http://yugiohjcj.1s.fr/
 */

#include "main.h"

int main(int argc, char *argv[]){

	/* The constants (information about the game) */
	const char * name = "shopeuros_client\0";
	const char * description = "It is a 1 and 2 players game. You must take the coins and bills on the ground before the others players. The goal is to have a lot of money\0";
	const char * author = "YuGiOhJCJ <yugiohjcj@1s.fr>\0";
	const char * version = "20090727\0";

	/* The constants (paths) */
	const char * const_path_icon = "/data/pictures/icons/icon.bmp\0";
	const char * const_path_map1 = "/data/pictures/maps/map1.bmp\0";
	const char * const_path_coin = "/data/pictures/objects/coin.bmp\0";
	const char * const_path_bill = "/data/pictures/objects/bill.bmp\0";
	const char * const_path_nothing = "/data/pictures/objects/nothing.bmp\0";
	const char * const_path_player1 = "/data/pictures/players/player1.bmp\0";
	const char * const_path_player2 = "/data/pictures/players/player2.bmp\0";
	const char * const_path_player3 = "/data/pictures/players/player3.bmp\0";
	const char * const_path_font = "/data/fonts/font.ttf\0";
	const char * const_path_menu_return = "/data/audio/menu_return.wav\0";
	const char * const_path_menu_switch = "/data/audio/menu_switch.wav\0";
	const char * const_path_shopeuros = "/data/audio/shopeuros.wav\0";
	const char * const_path_cool = "/data/audio/cool.wav\0";
	const char * const_path_super = "/data/audio/super.wav\0";
	const char * const_path_music = "/data/audio/music.ogg\0";

	/* The constants */
	const int const_time_next_move = 100;
	const int const_time_next_object = 15000;
	const int const_time_next_time_update = 1000;
	const int const_width = 320;
	const int const_height = 240;
	const int const_bpp = 32;
	const int const_font_size_titles = 14;
	const int const_font_size_menus = 16;
	const int const_font_size_players = 15;
	const int const_font_size_times = 17;
	const int const_font_color_r_titles = 100;
	const int const_font_color_g_titles = 100;
	const int const_font_color_b_titles = 100;
	const int const_font_color_r_menus = 155;
	const int const_font_color_g_menus = 155;
	const int const_font_color_b_menus = 155;
	const int const_font_color_r_player1 = 0;
	const int const_font_color_g_player1 = 0;
	const int const_font_color_b_player1 = 255;
	const int const_font_color_r_player2 = 0;
	const int const_font_color_g_player2 = 0;
	const int const_font_color_b_player2 = 0;
	const int const_font_color_r_player3 = 255;
	const int const_font_color_g_player3 = 0;
	const int const_font_color_b_player3 = 0;
	const int const_font_color_r_times = 200;
	const int const_font_color_g_times = 200;
	const int const_font_color_b_times = 200;
	const int const_move_increment = 10;
	const int const_max_time = 300000;
	const int const_max_score = 30;

	/* The structures */
	Player player1, player2, player3; /* the third player is the AI controlled player */
	Window window1;
	Bitmap bmp_map, bmp_coin, bmp_bill, bmp_nothing;
	Volume volume1;
	Text text_title, text_menu, text_parent_menu;
	Menu *menu1, *menu_current, *menu_tmp;
	Music music1;
	Sample sample_shopeuros, sample_super, sample_cool, sample_menu_return, sample_menu_switch;
	Game game1;
	Object object1;

	/* The SDL structures */
	SDL_Event event_menu, event_menu_control, event_play;

	char path[65536];
	long int ret_strtol; /* The return value of strtol */

	/* Check the arguments */
	if(displayHelpAndVersion(argc, argv, name, version, description, author)==-1){
		return(0);
	}

	/* Initialize SDL */
	if(SDL_Init(0)==-1) {
		fprintf(stderr, "main: error 1: SDL_Init: '%s'\n", SDL_GetError());
		return(-1);
	}

	/* Initialize SDL_ttf */
	if(TTF_Init()==-1){
		fprintf(stderr, "main: error 2: TTF_Init: '%s'\n", TTF_GetError());
		SDL_Quit();
		return(-1);
	}

	/*
	 * Initialize the audio device
	 * frequency : 44.1kHz
	 * format : Signed 16-bit samples (in system byte order)
	 * channels : 2
	 * bytes : 1024
	 * using 1024 byte chunks
	 */
	if(Mix_OpenAudio(44100, MIX_DEFAULT_FORMAT, 2, 1024)==-1){
		fprintf(stderr, "main: error 4: Mix_OpenAudio: '%s'\n", Mix_GetError());
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the path */
	strcpy(path, getPath(argc, argv));

	/* Initialize the windows */
	if(sprintf(window1.icon, "%s%s", path, const_path_icon)<0){
		fprintf(stderr, "main: error 5: sprintf\n");
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initWindow(const_width, const_height, const_bpp, getVideoModeFlags(argc, argv), name, window1.icon, &window1) == -1){
		fprintf(stderr, "main: error 6: initWindow\n");
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the bitmaps */
	if(sprintf(bmp_map.path, "%s%s", path, const_path_map1)<0){
		fprintf(stderr, "main: error 7: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initBitmap(0, 0, bmp_map.path, &bmp_map)==-1){
		fprintf(stderr, "main: error 8: initBitmap\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(bmp_coin.path, "%s%s", path, const_path_coin)<0){
		fprintf(stderr, "main: error 9: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initBitmap(0, 0, bmp_coin.path, &bmp_coin)==-1){
		fprintf(stderr, "main: error 10: initBitmap\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(bmp_bill.path, "%s%s", path, const_path_bill)<0){
		fprintf(stderr, "main: error 11: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initBitmap(0, 0, bmp_bill.path, &bmp_bill)==-1){
		fprintf(stderr, "main: error 12: initBitmap\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(bmp_nothing.path, "%s%s", path, const_path_nothing)<0){
		fprintf(stderr, "main: error 13: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initBitmap(0, 0, bmp_nothing.path, &bmp_nothing)==-1){
		fprintf(stderr, "main: error 14: initBitmap\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the volumes */
	initVolume(MIX_MAX_VOLUME, MIX_MAX_VOLUME, &volume1);

	/* Initialize the musics and samples */
	if(sprintf(music1.path, "%s%s", path, const_path_music)<0){
		fprintf(stderr, "main: error 15: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initMusic(music1.path, volume1.music, &music1)==-1){
		fprintf(stderr, "main: error 16: initMusic\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(sample_menu_return.path, "%s%s", path, const_path_menu_return)<0){
		fprintf(stderr, "main: error 17: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initSample(sample_menu_return.path, volume1.sample, &sample_menu_return)==-1){
		fprintf(stderr, "main: error 18: initSample\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(sample_menu_switch.path, "%s%s", path, const_path_menu_switch)<0){
		fprintf(stderr, "main: error 19: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initSample(sample_menu_switch.path, volume1.sample, &sample_menu_switch)==-1){
		fprintf(stderr, "main: error 20: initSample\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(sample_shopeuros.path, "%s%s", path, const_path_shopeuros)<0){
		fprintf(stderr, "main: error 21: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initSample(sample_shopeuros.path, volume1.sample, &sample_shopeuros)==-1){
		fprintf(stderr, "main: error 22: initSample\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(sample_cool.path, "%s%s", path, const_path_cool)<0){
		fprintf(stderr, "main: error 23: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initSample(sample_cool.path, volume1.sample, &sample_cool)==-1){
		fprintf(stderr, "main: error 24: initSample\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(sample_super.path, "%s%s", path, const_path_super)<0){
		fprintf(stderr, "main: error 25: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initSample(sample_super.path, volume1.sample, &sample_super)==-1){
		fprintf(stderr, "main: error 26: initSample\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the menus */
	menu1=initMenu();

	/* Initilialize the current menu */
	menu_current=menu1;

	/* Initialize the games */
	initGame(SDL_GetTicks(), const_time_next_move, const_time_next_object, in, stopped, const_max_time, const_max_score, normal, two_players_one_cpu, const_move_increment, &game1);

	/* Initialize the players */
	if(sprintf(player1.bitmap.path, "%s%s", path, const_path_player1)<0){
		fprintf(stderr, "main: error 27: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(player1.score.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 28: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initPlayer(window1, 0, game1.max_score, 0, 0, 0, 0, const_font_color_r_player1, const_font_color_g_player1, const_font_color_b_player1, const_font_size_players, player1.bitmap.path, player1.score.font.path, &player1, SDLK_UP, SDLK_DOWN, SDLK_LEFT, SDLK_RIGHT)==-1){
		fprintf(stderr, "main: error 29: initPlayer\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(player2.bitmap.path, "%s%s", path, const_path_player2)<0){
		fprintf(stderr, "main: error 30: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(player2.score.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 31: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initPlayer(window1, 0, game1.max_score, window1.sfc->w, window1.sfc->h, window1.sfc->w, 0, const_font_color_r_player2, const_font_color_g_player2, const_font_color_b_player2, const_font_size_players, player2.bitmap.path, player2.score.font.path, &player2, SDLK_KP8, SDLK_KP2, SDLK_KP4, SDLK_KP6)==-1){
		fprintf(stderr, "main: error 32: initPlayer\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(player3.bitmap.path, "%s%s", path, const_path_player3)<0){
		fprintf(stderr, "main: error 33: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(player3.score.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 34: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initPlayer(window1, 0, game1.max_score, (window1.sfc->w/2), (window1.sfc->h/2), (window1.sfc->w/2), 0, const_font_color_r_player3, const_font_color_g_player3, const_font_color_b_player3, const_font_size_players, player3.bitmap.path, player3.score.font.path, &player3, 0, 0, 0, 0)==-1){
		fprintf(stderr, "main: error 35: initPlayer\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the times */
	if(sprintf(game1.time.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 36: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initTime(window1, game1.time.value, game1.time.max_value, window1.sfc->w, window1.sfc->h, const_font_color_r_times, const_font_color_g_times, const_font_color_b_times, const_font_size_times, &game1.time)==-1){
		fprintf(stderr, "main: error 37: initTime\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the fonts */
	if(sprintf(text_title.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 38: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initText(window1, name, 0, window1.sfc->h, const_font_color_r_titles, const_font_color_g_titles, const_font_color_b_titles, const_font_size_titles, &text_title)==-1){
		fprintf(stderr, "main: error 39: initText\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(text_menu.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 40: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initText(window1, menu_current->label, (window1.sfc->w/2), (window1.sfc->h/2), const_font_color_r_menus, const_font_color_g_menus, const_font_color_b_menus, const_font_size_menus, &text_menu)==-1){
		fprintf(stderr, "main: error 41: initText\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(sprintf(text_parent_menu.font.path, "%s%s", path, const_path_font)<0){
		fprintf(stderr, "main: error 42: sprintf\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}
	if(initText(window1, ">\0", (window1.sfc->w/2), ((window1.sfc->h/2)-text_menu.font.size), const_font_color_r_menus, const_font_color_g_menus, const_font_color_b_menus, const_font_size_menus, &text_parent_menu)==-1){
		fprintf(stderr, "main: error 43: initText\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Initialize the object */
	initObject(&bmp_nothing, absent, &object1);

	/* Update the window */
	if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
		fprintf(stderr, "main: error 44: updateWindow\n");
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Play the music */
	Mix_HaltMusic();
	if(Mix_PlayMusic(music1.music, -1)==-1){
		fprintf(stderr, "main: error 45: Mix_PlayMusic: '%s'\n", Mix_GetError());
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	/* Play the sample 'shopeuros' on the channel 0 */
	Mix_HaltChannel(0);
	if(Mix_PlayChannel(0, sample_shopeuros.sample, 0)==-1) {
		fprintf(stderr, "main: error 46: Mix_PlayChannel: '%s'\n", Mix_GetError());
		freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
		Mix_CloseAudio();
		TTF_Quit();
		SDL_Quit();
		return(-1);
	}

	while(1){
		/* Wait for an event */
		while( SDL_WaitEvent(&event_menu) && (game1.status_menu==in) ){
			switch(event_menu.type){
				case SDL_QUIT:
					freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
					Mix_CloseAudio();
					TTF_Quit();
					SDL_Quit();
					return(0);
					break;
				case SDL_KEYDOWN:
					/* Play the sample 'menu_switch' on the channel 1 */
					Mix_HaltChannel(1);
					if(Mix_PlayChannel(1, sample_menu_switch.sample, 0)==-1) {
						fprintf(stderr, "main: error 47: Mix_PlayChannel: '%s'\n", Mix_GetError());
						freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
						Mix_CloseAudio();
						TTF_Quit();
						SDL_Quit();
						return(-1);
					}

					switch(event_menu.key.keysym.sym){
						case SDLK_ESCAPE:
							if(initText(window1, ">\0", (window1.sfc->w/2), ((window1.sfc->h/2)-text_menu.font.size), text_parent_menu.font.color.r, text_parent_menu.font.color.g, text_parent_menu.font.color.b, text_parent_menu.font.size, &text_parent_menu)==-1){
								fprintf(stderr, "main: error 48: initText\n");
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(-1);
							}
							menu_current=menu1;
							if(initText(window1, menu_current->label, (window1.sfc->w/2), (window1.sfc->h/2), text_menu.font.color.r, text_menu.font.color.g, text_menu.font.color.b, text_menu.font.size, &text_menu)==-1){
								fprintf(stderr, "main: error 49: initText\n");
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(-1);
							}
							if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
								fprintf(stderr, "main: error 50: updateWindow\n");
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(-1);
							}

							break;
						case SDLK_LEFT:
							if( (menu_tmp = menuPrevious(menu1, menu_current)) != NULL){
								menu_current=menu_tmp;
								if(initText(window1, menu_current->label, (window1.sfc->w/2), (window1.sfc->h/2), text_menu.font.color.r, text_menu.font.color.g, text_menu.font.color.b, text_menu.font.size, &text_menu)==-1){
									fprintf(stderr, "main: error 51: initText\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
									fprintf(stderr, "main: error 52: updateWindow\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							break;
						case SDLK_RIGHT:
							if( (menu_tmp = menuNext(menu1, menu_current)) != NULL){
								menu_current=menu_tmp;
								if(initText(window1, menu_current->label, (window1.sfc->w/2), (window1.sfc->h/2), text_menu.font.color.r, text_menu.font.color.g, text_menu.font.color.b, text_menu.font.size, &text_menu)==-1){
									fprintf(stderr, "main: error 53: initText\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
									fprintf(stderr, "main: error 54: updateWindow\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							break;
						case SDLK_RETURN:
							/* Play the sample 'menu_return' on the channel 1 */
							Mix_HaltChannel(2);
							if(Mix_PlayChannel(2, sample_menu_return.sample, 0)==-1) {
								fprintf(stderr, "main: error 55: Mix_PlayChannel: '%s'\n", Mix_GetError());
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(-1);
							}

							if(strcmp(menu_current->label, "Exit\0") == 0){
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(0);
							}
							else if(strcmp(menu_current->label, "1 player\0") == 0){
								game1.mode=one_player;
								if(gameStart(window1, &player1, &player2, &player3, &object1, &bmp_nothing, &game1, const_time_next_move, const_time_next_object)==-1){
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(0);
								}
							}
							else if(strcmp(menu_current->label, "2 players\0") == 0){
								game1.mode=two_players;
								if(gameStart(window1, &player1, &player2, &player3, &object1, &bmp_nothing, &game1, const_time_next_move, const_time_next_object)==-1){
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(0);
								}
							}
							else if(strcmp(menu_current->label, "2 players and 1 CPU\0") == 0){
								game1.mode=two_players_one_cpu;
								if(gameStart(window1, &player1, &player2, &player3, &object1, &bmp_nothing, &game1, const_time_next_move, const_time_next_object)==-1){
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(0);
								}
							}
							else if(strcmp(menu_current->label, "Fullscreen\0") == 0){
								window1.flags=SDL_SWSURFACE|SDL_FULLSCREEN;
								if(initWindow(window1.width, window1.height, window1.bpp, window1.flags, name, window1.icon, &window1) == -1){
									fprintf(stderr, "main: error 56: initWindow\n");
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
									fprintf(stderr, "main: error 57: updateWindow\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}

							}
							else if(strcmp(menu_current->label, "Window\0") == 0){
								window1.flags=SDL_SWSURFACE;
								if(initWindow(window1.width, window1.height, window1.bpp, window1.flags, name, window1.icon, &window1) == -1){
									fprintf(stderr, "main: error 58: initWindow\n");
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
									fprintf(stderr, "main: error 59: updateWindow\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}

							}
							else if( (ret_strtol=strtol(menu_current->label,NULL,10)) != 0){
								if(ret_strtol>99){
									initGame(0, 0, 0, in, stopped, ret_strtol, game1.max_score, game1.difficulty, game1.mode, game1.move_increment, &game1);

								}
								else{
									initGame(0, 0, 0, in, stopped, game1.max_time, ret_strtol, game1.difficulty, game1.mode, game1.move_increment, &game1);
								}
							}
							else if( strcmp(menu_current->label, "Mute samples\0") == 0){
								Mix_HaltChannel(-1);
								initVolume(volume1.music, 0, &volume1);
								if(initSample(sample_menu_return.path, volume1.sample, &sample_menu_return)==-1){
									fprintf(stderr, "main: error 60: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_menu_switch.path, volume1.sample, &sample_menu_switch)==-1){
									fprintf(stderr, "main: error 61: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_shopeuros.path, volume1.sample, &sample_shopeuros)==-1){
									fprintf(stderr, "main: error 62: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_cool.path, volume1.sample, &sample_cool)==-1){
									fprintf(stderr, "main: error 63: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_super.path, volume1.sample, &sample_super)==-1){
									fprintf(stderr, "main: error 64: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Samples volume 1/3\0") == 0){
								Mix_HaltChannel(-1);
								initVolume(volume1.music, MIX_MAX_VOLUME/3, &volume1);
								if(initSample(sample_menu_return.path, volume1.sample, &sample_menu_return)==-1){
									fprintf(stderr, "main: error 65: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_menu_switch.path, volume1.sample, &sample_menu_switch)==-1){
									fprintf(stderr, "main: error 66: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_shopeuros.path, volume1.sample, &sample_shopeuros)==-1){
									fprintf(stderr, "main: error 67: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_cool.path, volume1.sample, &sample_cool)==-1){
									fprintf(stderr, "main: error 68: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_super.path, volume1.sample, &sample_super)==-1){
									fprintf(stderr, "main: error 69: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Samples volume 2/3\0") == 0){
								Mix_HaltChannel(-1);
								initVolume(volume1.music, MIX_MAX_VOLUME/2, &volume1);
								if(initSample(sample_menu_return.path, volume1.sample, &sample_menu_return)==-1){
									fprintf(stderr, "main: error 70: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_menu_switch.path, volume1.sample, &sample_menu_switch)==-1){
									fprintf(stderr, "main: error 71: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_shopeuros.path, volume1.sample, &sample_shopeuros)==-1){
									fprintf(stderr, "main: error 72: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_cool.path, volume1.sample, &sample_cool)==-1){
									fprintf(stderr, "main: error 73: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_super.path, volume1.sample, &sample_super)==-1){
									fprintf(stderr, "main: error 74: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Samples volume 3/3\0") == 0){
								Mix_HaltChannel(-1);
								initVolume(volume1.music, MIX_MAX_VOLUME, &volume1);
								if(initSample(sample_menu_return.path, volume1.sample, &sample_menu_return)==-1){
									fprintf(stderr, "main: error 75: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_menu_switch.path, volume1.sample, &sample_menu_switch)==-1){
									fprintf(stderr, "main: error 76: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_shopeuros.path, volume1.sample, &sample_shopeuros)==-1){
									fprintf(stderr, "main: error 77: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_cool.path, volume1.sample, &sample_cool)==-1){
									fprintf(stderr, "main: error 79: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								if(initSample(sample_super.path, volume1.sample, &sample_super)==-1){
									fprintf(stderr, "main: error 80: initSample\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Mute music\0") == 0){
								initVolume(0, volume1.sample, &volume1);
								if(initMusic(music1.path, volume1.music, &music1)==-1){
									fprintf(stderr, "main: error 81: initMusic\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								/* Play the music */
								Mix_HaltMusic();
								if(Mix_PlayMusic(music1.music, -1)==-1){
									fprintf(stderr, "main: error 82: Mix_PlayMusic: '%s'\n", Mix_GetError());
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Music volume 1/3\0") == 0){
								initVolume(MIX_MAX_VOLUME/3, volume1.sample, &volume1);
								if(initMusic(music1.path, volume1.music, &music1)==-1){
									fprintf(stderr, "main: error 83: initMusic\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								/* Play the music */
								Mix_HaltMusic();
								if(Mix_PlayMusic(music1.music, -1)==-1){
									fprintf(stderr, "main: error 84: Mix_PlayMusic: '%s'\n", Mix_GetError());
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Music volume 2/3\0") == 0){
								initVolume(MIX_MAX_VOLUME/2, volume1.sample, &volume1);
								if(initMusic(music1.path, volume1.music, &music1)==-1){
									fprintf(stderr, "main: error 85: initMusic\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								/* Play the music */
								Mix_HaltMusic();
								if(Mix_PlayMusic(music1.music, -1)==-1){
									fprintf(stderr, "main: error 86: Mix_PlayMusic: '%s'\n", Mix_GetError());
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Music volume 3/3\0") == 0){
								Mix_HaltMusic();
								initVolume(MIX_MAX_VOLUME, volume1.sample, &volume1);
								if(initMusic(music1.path, volume1.music, &music1)==-1){
									fprintf(stderr, "main: error 87: initMusic\n");
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
								/* Play the music */
								if(Mix_PlayMusic(music1.music, -1)==-1){
									fprintf(stderr, "main: error 88: Mix_PlayMusic: '%s'\n", Mix_GetError());
									freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
									Mix_CloseAudio();
									TTF_Quit();
									SDL_Quit();
									return(-1);
								}
							}
							else if( strcmp(menu_current->label, "Easy\0") == 0){
								initGame(game1.time_current, game1.time_next_move, game1.time_next_object, in, stopped, game1.max_time, game1.max_score, easy, game1.mode, game1.move_increment, &game1);
							}
							else if( strcmp(menu_current->label, "Normal\0") == 0){
								initGame(game1.time_current, game1.time_next_move, game1.time_next_object, in, stopped, game1.max_time, game1.max_score, normal, game1.mode, game1.move_increment, &game1);
							}
							else if( strcmp(menu_current->label, "Hard\0") == 0){
								initGame(game1.time_current, game1.time_next_move, game1.time_next_object, in, stopped, game1.max_time, game1.max_score, hard, game1.mode, game1.move_increment, &game1);
							}
							else if( strcmp(menu_current->label, "P1 UP\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player1.money, game1.max_score, player1.bitmap.rct.x, player1.bitmap.rct.y, player1.score.font.x, player1.score.font.y, player1.score.font.color.r, player1.score.font.color.g, player1.score.font.color.b, player1.score.font.size, player1.bitmap.path, player1.score.font.path, &player1, event_menu_control.key.keysym.sym, player1.controls.down, player1.controls.left, player1.controls.right)==-1){
											fprintf(stderr, "main: error 89: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P1 DOWN\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player1.money, game1.max_score, player1.bitmap.rct.x, player1.bitmap.rct.y, player1.score.font.x, player1.score.font.y, player1.score.font.color.r, player1.score.font.color.g, player1.score.font.color.b, player1.score.font.size, player1.bitmap.path, player1.score.font.path, &player1, player1.controls.up, event_menu_control.key.keysym.sym, player1.controls.left, player1.controls.right)==-1){
											fprintf(stderr, "main: error 90: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P1 LEFT\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player1.money, game1.max_score, player1.bitmap.rct.x, player1.bitmap.rct.y, player1.score.font.x, player1.score.font.y, player1.score.font.color.r, player1.score.font.color.g, player1.score.font.color.b, player1.score.font.size, player1.bitmap.path, player1.score.font.path, &player1, player1.controls.up, player1.controls.down, event_menu_control.key.keysym.sym, player1.controls.right)==-1){
											fprintf(stderr, "main: error 91: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P1 RIGHT\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player1.money, game1.max_score, player1.bitmap.rct.x, player1.bitmap.rct.y, player1.score.font.x, player1.score.font.y, player1.score.font.color.r, player1.score.font.color.g, player1.score.font.color.b, player1.score.font.size, player1.bitmap.path, player1.score.font.path, &player1, player1.controls.up, player1.controls.down, player1.controls.left, event_menu_control.key.keysym.sym)==-1){
											fprintf(stderr, "main: error 92: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P2 UP\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player2.money, game1.max_score, player2.bitmap.rct.x, player2.bitmap.rct.y, player2.score.font.x, player2.score.font.y, player2.score.font.color.r, player2.score.font.color.g, player2.score.font.color.b, player2.score.font.size, player2.bitmap.path, player2.score.font.path, &player2, event_menu_control.key.keysym.sym, player2.controls.down, player2.controls.left, player2.controls.right)==-1){
											fprintf(stderr, "main: error 93: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P2 DOWN\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player2.money, game1.max_score, player2.bitmap.rct.x, player2.bitmap.rct.y, player2.score.font.x, player2.score.font.y, player2.score.font.color.r, player2.score.font.color.g, player2.score.font.color.b, player2.score.font.size, player2.bitmap.path, player2.score.font.path, &player2, player2.controls.up, event_menu_control.key.keysym.sym, player2.controls.left, player2.controls.right)==-1){
											fprintf(stderr, "main: error 94: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P2 LEFT\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player2.money, game1.max_score, player2.bitmap.rct.x, player2.bitmap.rct.y, player2.score.font.x, player2.score.font.y, player2.score.font.color.r, player2.score.font.color.g, player2.score.font.color.b, player2.score.font.size, player2.bitmap.path, player2.score.font.path, &player2, player2.controls.up, player2.controls.down, event_menu_control.key.keysym.sym, player2.controls.right)==-1){
											fprintf(stderr, "main: error 95: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else if( strcmp(menu_current->label, "P2 RIGHT\0") == 0){

								while( SDL_WaitEvent(&event_menu_control) ){
									if(event_menu_control.type==SDL_KEYDOWN){
										if(initPlayer(window1, player2.money, game1.max_score, player2.bitmap.rct.x, player2.bitmap.rct.y, player2.score.font.x, player2.score.font.y, player2.score.font.color.r, player2.score.font.color.g, player2.score.font.color.b, player2.score.font.size, player2.bitmap.path, player2.score.font.path, &player2, player2.controls.up, player2.controls.down, player2.controls.left, event_menu_control.key.keysym.sym)==-1){
											fprintf(stderr, "main: error 96: initPlayer\n");
											freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
											Mix_CloseAudio();
											TTF_Quit();
											SDL_Quit();
											return(-1);
										}
										break;
									}/* End of while( SDL_WaitEvent(&event_menu_control) )*/
								}
							}
							else{
								if( (menu_tmp = menuSub(menu1, menu_current)) != NULL){
									if(sprintf(text_parent_menu.string, "%s %s", text_parent_menu.string, menu_current->label)<0){
										fprintf(stderr, "main: error 97: sprintf\n");
										freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
										Mix_CloseAudio();
										TTF_Quit();
										SDL_Quit();
										return(-1);
									}
									if(initText(window1, text_parent_menu.string, (window1.sfc->w/2), (window1.sfc->h/2)-text_menu.font.size, text_parent_menu.font.color.r, text_parent_menu.font.color.g, text_parent_menu.font.color.b, text_parent_menu.font.size, &text_parent_menu)==-1){
										fprintf(stderr, "main: error 98: initText\n");
										freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
										Mix_CloseAudio();
										TTF_Quit();
										SDL_Quit();
										return(-1);
									}
									menu_current=menu_tmp;
									if(initText(window1, menu_current->label, (window1.sfc->w/2), (window1.sfc->h/2), text_menu.font.color.r, text_menu.font.color.g, text_menu.font.color.b, text_menu.font.size, &text_menu)==-1){
										fprintf(stderr, "main: error 99: initText\n");
										freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
										Mix_CloseAudio();
										TTF_Quit();
										SDL_Quit();
										return(-1);
									}
									if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
										fprintf(stderr, "main: error 100: updateWindow\n");
										freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
										Mix_CloseAudio();
										TTF_Quit();
										SDL_Quit();
										return(-1);
									}
								}
							}
							break;
						default:
							/* Nothing to do */
							break;
					}
					break;
			}/* End of switch(event_menu.type) */
		}/* Enf of while( SDL_WaitEvent(&event_menu) && (game1.status_menu==in) ) */
		while(game1.status_menu==out){
			while(SDL_PollEvent(&event_play)){
				switch(event_play.type){
					case SDL_QUIT:
						freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
						Mix_CloseAudio();
						TTF_Quit();
						SDL_Quit();
						return(0);
						break;
					case SDL_KEYDOWN:
						if(event_play.key.keysym.sym==player1.controls.up){
							moveUp(&player1.bitmap.rct, game1, player2.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player2.controls.up){
							moveUp(&player2.bitmap.rct, game1, player1.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player1.controls.down){
							moveDown(player1.bitmap.sfc, &player1.bitmap.rct, window1.sfc, game1, player2.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player2.controls.down){
							moveDown(player2.bitmap.sfc, &player2.bitmap.rct, window1.sfc, game1, player1.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player1.controls.left){
							moveLeft(&player1.bitmap.rct, game1, player2.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player2.controls.left){
							moveLeft(&player2.bitmap.rct, game1, player1.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player1.controls.right){
							moveRight(player1.bitmap.sfc, &player1.bitmap.rct, window1.sfc, game1, player2.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==player2.controls.right){
							moveRight(player2.bitmap.sfc, &player2.bitmap.rct, window1.sfc, game1, player1.bitmap.rct, player3.bitmap.rct);
						}
						if(event_play.key.keysym.sym==SDLK_ESCAPE){
							if(gameStop(&game1)==-1){
								fprintf(stderr, "main: error 101: gameStop\n");
								freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
								Mix_CloseAudio();
								TTF_Quit();
								SDL_Quit();
								return(-1);
							}
						}
						break;
				}/* End of switch(event_play.type) */
			}/* End of while(SDL_PollEvent(&event_play) */

			/* Get the current time */
			game1.time_current = SDL_GetTicks();

			if(updateObject(&bmp_coin, &bmp_bill, &bmp_nothing, &object1, window1, &game1, const_time_next_object)==-1){
				fprintf(stderr, "main: error 102: updateObject\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updatePlayer(player3.bitmap.sfc, &player3.bitmap.rct, object1, &game1, player1.bitmap.rct, player2.bitmap.rct, window1.sfc, const_time_next_move)==-1){
				fprintf(stderr, "main: error 103: updatePlayer\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateScore(window1, &player1, sample_cool.sample, sample_super.sample, &object1, game1.max_score)==-1){
				fprintf(stderr, "main: error 104: updateScore\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateScore(window1, &player2, sample_cool.sample, sample_super.sample, &object1, game1.max_score)==-1){
				fprintf(stderr, "main: error 105: updateScore\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateScore(window1, &player3, sample_cool.sample, sample_super.sample, &object1, game1.max_score)==-1){
				fprintf(stderr, "main: error 106: updateScore\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateTime(window1, window1.sfc->w, window1.sfc->h, const_font_color_r_times, const_font_color_g_times, const_font_color_b_times, const_font_size_times, &game1, const_time_next_time_update)==-1){
				fprintf(stderr, "main: error 107: updateTime\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateGameStatus(player1.score.value, player2.score.value, player3.score.value, &game1)==-1){
				fprintf(stderr, "main: error 108: updateGameStatus\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
			if(updateWindow(window1.sfc, bmp_map.sfc, text_title.font.sfc, text_title.font.rct, text_menu.font.sfc, text_menu.font.rct, text_parent_menu.font.sfc, text_parent_menu.font.rct, player1.bitmap.sfc, player1.bitmap.rct, player2.bitmap.sfc, player2.bitmap.rct, player3.bitmap.sfc, player3.bitmap.rct, player1.score.font.sfc, player1.score.font.rct, player2.score.font.sfc, player2.score.font.rct, player3.score.font.sfc, player3.score.font.rct, game1.time.font.sfc, game1.time.font.rct, object1, game1) == -1){
				fprintf(stderr, "main: error 109: updateWindow\n");
				freeAll(bmp_nothing.sfc, bmp_bill.sfc, bmp_coin.sfc, bmp_map.sfc, player3.bitmap.sfc, player3.score.font.sfc, player2.bitmap.sfc, player2.score.font.sfc, player1.bitmap.sfc, player1.score.font.sfc, window1.sfc, text_title.font.ttf, text_menu.font.ttf, text_parent_menu.font.ttf, sample_super.sample, sample_cool.sample, sample_shopeuros.sample, sample_menu_switch.sample, sample_menu_return.sample, music1.music, menu1);
				Mix_CloseAudio();
				TTF_Quit();
				SDL_Quit();
				return(-1);
			}
		}
	}/* End of while(1) */
}
