/**
 * \file menu.c
 * \brief The functions for menu
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * \version 20090726
 * \author YuGiOhJCJ <yugiohjcj@1s.fr> http://yugiohjcj.1s.fr/
 */

#include<stdlib.h> /* For NULL, stderr */
#include<string.h> /* For strcpy */
#include "menu.h" /* For Menu */ 

Menu* menuCreate(char* label, Menu *next, Menu *sub){
	Menu *menu;
	menu = malloc(sizeof(Menu));
	strcpy(menu->label, label);
	menu->next = next;
	menu->sub = sub;
	return(menu);
}
 
Menu* menuNext(Menu *menu, Menu *menu_current){

	Menu * menu_sub;
 
	/* if it is found */
	if( (strcmp(menu->label, menu_current->label) == 0) && (menu->next != NULL) ){
		return(menu->next);
	}
	/* if it has a sub */
	if(menu->sub != NULL){
		if( (menu_sub = menuNext(menu->sub, menu_current)) != NULL){
			return(menu_sub);
		}
	}
	/* if it has a next */
	if(menu->next != NULL){
		return(menuNext(menu->next, menu_current));
	}
	return(NULL);
}

Menu* menuPrevious(Menu *menu, Menu *menu_current){

	Menu * menu_sub;
 
	/* if it is found */
	if( (menu->next != NULL) && (strcmp(menu->next->label, menu_current->label) == 0) ){
		return(menu);
	}
	/* if it has a sub */
	if(menu->sub != NULL){
		if( (menu_sub = menuPrevious(menu->sub, menu_current)) != NULL){
			return(menu_sub);
		}
	}
	/* if it has a next */
	if(menu->next != NULL){
		return(menuPrevious(menu->next, menu_current));
	}
	return(NULL);
}

Menu* menuSub(Menu *menu, Menu *menu_current){
	Menu * menu_sub;
 
	/* if it is found */
	if( (menu->sub != NULL) && (strcmp(menu->label, menu_current->label) == 0) ){
		return(menu->sub);
	}
	/* if it has a sub */
	if(menu->sub != NULL){
		if( (menu_sub = menuSub(menu->sub, menu_current)) != NULL){
			return(menu_sub);
		}
	}
	/* if it has a next */
	if(menu->next != NULL){
		return(menuSub(menu->next, menu_current));
	}
	return(NULL);
}

Menu* menuGet(Menu *menu, char* label){
	Menu * menu_sub;
 
	/* if it is found */
	if( (strcmp(menu->label, label) == 0) ){
		return(menu);
	}
	/* if it has a sub */
	if(menu->sub != NULL){
		if( (menu_sub = menuGet(menu->sub, label)) != NULL){
			return(menu_sub);
		}
	}
	/* if it has a next */
	if(menu->next != NULL){
		return(menuGet(menu->next, label));
	}
	return(NULL);
}

void menuFree(Menu *menu){
	if(menu->sub != NULL){
		menuFree(menu->sub);
	}
	if(menu->next != NULL){
		menuFree(menu->next);
	}
	free(menu);
	menu=NULL;
} 
