/**
 * \file menu.h
 * \brief The header for menu.c
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * \version 20090726
 * \author YuGiOhJCJ <yugiohjcj@1s.fr> http://yugiohjcj.1s.fr/
 */

#ifndef menu_h
#define menu_h

#include<stdio.h> /* For printf, fprintf */
#include<stdlib.h> /* For NULL, stderr */
#include<string.h> /* For strcpy */

/**
 * \struct menu
 * \brief a menu
 */
typedef struct menu{
	char label[255]; /**< the label */
	struct menu *next; /**< the next menu */
	struct menu *sub; /**< the sub menu */
} Menu; /**< the Menu structure */

/**
 * \fn Menu* menuCreate(char* label, Menu *next, Menu *sub)
 * \brief create a menu with a label, a next menu and a sub menu
 * \param label a string (the label)
 * \param next a pointer to a Menu structure (the next menu)
 * \param sub a pointer to a Menu structure (the sub menu)
 * \return a pointer to a Menu structure (the menu created)
 */
Menu* menuCreate(char* label, Menu *next, Menu *sub);

/**
 * \fn Menu* menuNext(Menu *menu, Menu *menu_current)
 * \brief get the next menu
 * \param menu a pointer to a Menu structure (the menu)
 * \param menu_current a pointer to a Menu structure (the current menu)
 * \return a pointer to a Menu structure (the next menu)
 */
Menu* menuNext(Menu *menu, Menu *menu_current);

/**
 * \fn Menu* menuPrevious(Menu *menu, Menu *menu_current)
 * \brief get the previous menu
 * \param menu a pointer to a Menu structure (the menu)
 * \param menu_current a pointer to a Menu structure (the current menu)
 * \return a pointer to a Menu structure (the previous menu)
 */
Menu* menuPrevious(Menu *menu, Menu *menu_current);

/**
 * \fn Menu* menuSub(Menu *menu, Menu *menu_current)
 * \brief get the sub menu
 * \param menu a pointer to a Menu structure (the menu)
 * \param menu_current a pointer to a Menu structure (the current menu)
 * \return a pointer to a Menu structure (the sub menu)
 */
Menu* menuSub(Menu *menu, Menu *menu_current);

/**
 * \fn Menu* menuGet(Menu *menu, char* label)
 * \brief get the first menu which the label is the given label
 * \param menu a pointer to a Menu structure (the menu)
 * \param label a string (the label)
 * \return a pointer to a Menu structure (the first menu which the label is the given label)
 */
Menu* menuGet(Menu *menu, char* label);

/**
 * \fn void menuFree(Menu *menu)
 * \brief Free a menu
 * \param menu a pointer to a Menu structure (the menu which must be freed)
 * \return nothing
 */
void menuFree(Menu *menu);

#endif
